//dog whistle JTN 20230322

//Second version with a different mouth design working with harder blowing and generating strong 3xf0


$fa=3;
$fs=0.25;
eps=1/128;

bd = 10;			//base diameter
bc = -2;			//bottom cut	(make bottom flat this many mm from center line)
rr = 1;				//rounding radius

il = 20;			//inlet length
io = 2;				//inlet offset (direction Y, away from origin)
is = [0.5,0.3];		//inlet scaling (portion of base form size at the starting end)
ies = [0.6,0.6];	//inlet scaling towards the mouth
ia = 3;				//inlet angle (from Z towards Y)

my = 3;				// = mouth depth
mz = il;			//mouth z position
mw = 10;			//mouth width

rl = 8;				//resonance cavity length
rw = 6;				//resonance cavity width
rh = 3.5;			//resonance cavity height
ro = 0.5;			//resonance cavity offset (y)
rs = [0.7,0.7];		//resonanse cavity scaling
bl = il+rl+1.5;		//base length

mt = 3;				//mount thicknes
ml = 10;			//mount length
mo = 8;				//carrying strap hole offset
md = 4;				//strap hole diameter
er = 10;			//top edge radius
lt = 1.5;			//bottom lip thickness
ly = 1;				//bottom lip y
lz = 0.5;			//bottom lip z

//mouth outline
//p = [[0,0],[0,1],[5,8],[5,0]]; 	//steeper lip
//p = [[0,0],[0,1],[5,10],[5,0]];	// gentler lip
p = [[0,0],[0,1.5],[5,8],[5,0]];	// gentler lip with a bit longer straight part

module base_form(h=bl,s=1) {
	linear_extrude(height=h,scale=s,convexity=5) offset(rr) offset(-rr) difference() {
			circle(d=bd);
			translate([0,-(bd/2-bc)]) square(bd,center=true);
	}
}

difference() {
	base_form();		
	rotate([-ia,0,0]) translate([0,io,-0.5]) scale(is) base_form(h=il+1,s=ies);									//inlet
	translate([0,my,mz]) rotate([90,0,90]) linear_extrude(height=mw,convexity=5,center=true) polygon(p);		//mouth
	translate([0,ro,il]) scale(rs) base_form(h=rl);																//resonance cavity
	//translate([bd/2,0,bl/2]) cube([bd,bd,bl],center=true);													//uncomment for partial cut-away
}

difference() {		//Put a star (*) in front of this line if you only want to print the sound section for a test part
	union() {
		translate([0,0,bl]) hull() {																			//neck
			base_form(h=eps);
			translate([0,0,mt]) linear_extrude(height=eps,convexity=5) offset(rr) offset(-rr) square([bd,mt],center=true);
		}
		translate([0,0,mt+bl]) intersection() {																	//rounded top
			linear_extrude(height=ml,convexity=5) offset(rr) offset(-rr)square([bd,mt],center=true);
			rotate([90,0,0]) cylinder(h=mt+1,r=er,center=true);
		}
		translate([0,ly,lz]) rotate_extrude(angle=180,convexity=5) translate([bd/2-1,0]) circle(d=lt);			//lip
	}
	translate([0,0,-10]) cube(20,center=true);																	//clean bottom
	translate([0,0,bl+mo]) rotate([90,0,0]) cylinder(h=mt+1,d=md,center=true);
}
		

